<?php

namespace Teknisa\PED\Modules\Pedidos\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Doctrine\ORM\Query\ResultSetMapping;

class Ped05300RecalculoPrecoPedidoFactory {
    
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection       = $entityManager->getConnection();
        $this->entityManager    = $entityManager;
    }
    
    public function getItemPed($row){
        
        $sql = "SELECT P.CDFILIAL, P.NRPEDIDO, P.IDSITPEDIDO, C.NMFANTCLIE, P.DTPEDIDO, P.DTENTPED,
                       P.CDVENDEDOR, VALOR_PEDIDO(P.CDFILIAL, P.NRPEDIDO) AS VRTOTAPED, P.CDPRECOBASE,
                       I.NRITEMPED, I.IDSITITEMPED, I.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, I.QTITEMPED,
                       P.SGUNIDADE, I.VRPREUNITPED, I.VRDESITPED, ((I.QTITEMPED * I.VRPREUNITPED)- I.VRDESITPED) VRTOTAITEM,
                       I.QTITEMPED - I.QTEXPITEMPED AS QTDEAEXP, I.QTEXPITEMPED, I.DTENTITPED, I.IDITPEDDIFER,
                       I.VRDESITPED, V.NMFANVEN
                 FROM PEDIDO P, CLIENTE C, ITEMPEDIDO I, PRODUTO P, VENDEDOR V
                     WHERE P.CDFILIAL = :P_CDFILIAL
                           AND P.NRPEDIDO BETWEEN :P_NRPEDINICIAL AND :P_NRPEDFINAL
                           AND P.IDSITPEDIDO IN ('1', '2', '6')
                           AND P.CDCLIENTE = C.CDCLIENTE
                           AND P.CDFILIAL = I.CDFILIAL
                           AND P.NRPEDIDO = I.NRPEDIDO
                           AND I.CDPRODUTO = P.CDPRODUTO
                           AND P.CDVENDEDOR = V.CDVENDEDOR";
                           
        $params = array('P_CDFILIAL'		=> $row['CDFILIAL'],
						'P_NRPEDINICIAL'	=> $row['NRPEDIDOINI'],
						'P_NRPEDFINAL'		=> $row['NRPEDIDOFIM']
		);


		$std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getPrecoPromo($pedido){
        
        $sql = "SELECT MAX(PP.VRTOTALPROMO) AS VRITEPREBASE
                FROM ITEMPREBASE I, PROMOPRBASE PP
                    WHERE (I.CDPRECOBASE     = :P_CDPRECOBASE)
                       AND (I.CDPRODUTO       = :P_CDPRODUTO)
                       AND (PP.CDPRECOBASE    = I.CDPRECOBASE )
                       AND (PP.CDPRODUTO      = I.CDPRODUTO   )
                       AND (PP.DTINIVALIPB    = I.DTINIVALIPB )
                       AND (TO_CHAR(TO_DATE(:P_DTPEDIDO),'DD/MM/YYYY') BETWEEN PP.DTINIPROMO AND  NVL(PP.DTFINPROMO, SYSDATE))
                       AND ((PP.IDDIASPROMO =(TO_CHAR(TO_DATE(:P_DTPEDIDO),'D')))OR(PP.IDDIASPROMO ='8'))
                       AND (PP.IDSTATUSPROMO = 'AT')";
                       
        $params = array('P_CDPRECOBASE' => $pedido['CDPRECOBASE'],
                        'P_CDPRODUTO'   => $pedido['CDPRODUTO'],
                        'P_DTPEDIDO'    => $pedido['DTPEDIDO']
        );
        
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function getPrecoBase($pedido, $dtPedido){
        
        $sql = "SELECT MAX(VRITEPREBASE) VRITEPREBASE
                 FROM ITEMPREBASE
                     WHERE CDPRECOBASE =  :P_CDPRECOBASE
                       AND CDPRODUTO   =  :P_CDPRODUTO
                       AND (TO_CHAR(TO_DATE(:P_DTPEDIDO),'DD/MM/YYYY') BETWEEN DTINIVALIPB AND NVL(DTFIMVALIPB, SYSDATE))";
                       
        $params = array('P_CDPRECOBASE' => $pedido['CDPRECOBASE'],
                        'P_CDPRODUTO'   => $pedido['CDPRODUTO'],
                        'P_DTPEDIDO'    => $dtPedido
        );

        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    public function recalculaVrPed($cdfilial, $pedinicial, $pedfinal, $dtatual, $tabPreini, $tabPrefin){
        

        try {
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'RECALCULA_PRECOPED');           //('RECALCULA_PRECOPED')
            $procedure->addParam(new Param('P_CDFILIAL'     , Param::PARAM_INPUT, $cdfilial     , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDINICIAL' , Param::PARAM_INPUT, $pedinicial   , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPEDFINAL'   , Param::PARAM_INPUT, $pedfinal     , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPRECOORIG'  , Param::PARAM_INPUT, $tabPreini    , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDPRECODEST'  , Param::PARAM_INPUT, $tabPrefin    , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_IDDTATUAL'    , Param::PARAM_INPUT, $dtatual      , Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRERRO'       , Param::PARAM_OUTPUT,''            , Param::PARAM_TYPE_STR, 1));
            
           return  $procedure->execute();

        
        } catch (\Exception $e) {
            throw $e;
        }
    }
   
}